@@ -1,3 +1,5 @@
+from typing import AnyStr, List
+import pandas as pd
 import pandas.errors
 import os
 from nonebot_plugin_htmlrender import template_to_pic
@@ -164,8 +166,9 @@ class TodoList:
     def write_data(self):
         self._list.sort()
         if len(self._list) == 0:
-            df = None
+            df = pd.DataFrame(columns=['name', 'start_date', 'end_date', 'priority'])
             df.to_csv(self.path + '/' + self._user + '.csv', index=False)
+
         else:
             df = DataFrame()
             for token in self._list:
@@ -174,15 +177,15 @@ class TodoList:
             df.to_csv(self.path + '/' + self._user + '.csv', index=False)
 
     async def get_img(self):
-        list_by_date: list[(str, int, list[TodoToken])] = list[list[TodoToken]]()
+        list_by_date: List[(str, int, List[TodoToken])] = list()
         now_date = ""
         date_count = 0
-        now_date_token: list[TodoToken] = list()
+        now_date_token: List[TodoToken] = list()
         for token in self._list:
             if token.end_date != now_date:
                 date_count += 1
                 now_date = token.end_date
-                now_date_token = list[TodoToken]()
+                now_date_token:List[TodoToken] = list()
                 list_by_date.append((now_date, token.time_left, now_date_token))
             now_date_token.append(token)
 
@@ -236,7 +239,7 @@ class TodoUtil:
         return self.todo_list.change_data(name, slot, content)
 
     def change_time(self, name: str, time: str):
-        return self.todo_list.change_data(name, 'time', time)
+        return self.todo_list.change_data(name, '_end_date', time)
 
     def finish_job(self, name: str):
         return self.remove_data(name)
